OpenApiFromSegments

Trait OpenApiFromSegments 

pub trait OpenApiFromSegments<'r>: FromSegments<'r> {
    // Required method
    fn path_multi_parameter(
        gen: &mut OpenApiGenerator,
        name: String,
    ) -> Result<Parameter>;
}
This trait is used to document a dynamic path segment that implements FromSegments. For example <param..> in route path.

Required Methods

fn path_multi_parameter( gen: &mut OpenApiGenerator, name: String, ) -> Result<Parameter>

Return a Parameter containing the information required to document the FromSegments path parameter.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<'r, T> OpenApiFromSegments<'r> for T
where T: FromSegments<'r> + JsonSchema,